/* Gateway function for compiling MexComputeLambda into a mex file. 
Written by Luca Cazzanti, Applied Physics Lab, University of Washington.
First complete version: Dec 1, 2009
$Id$
*/


#include <vector>
#include "mex.h"
#include "BrentExp.h"

using namespace idl;


void mexFunction( int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{

  /*Check for proper number of args */
  if (nrhs < 3)
    mexErrMsgTxt("Three arguments required!");
  if (nlhs > 3)
    mexErrMsgTxt("Too many output arguments.");

  /* Check input types */
  if (! mxIsNumeric(prhs[0]))
    mexErrMsgTxt("First arg must be numeric");
  if (! mxIsNumeric(prhs[1]))
    mexErrMsgTxt("Second arg must be numeric");
  if (! mxIsNumeric(prhs[2]))
    mexErrMsgTxt("Third arg must be numeric");


  /* Get pointers to input variables */
  double *classMean = mxGetPr(prhs[0]);
  double *simDomain = mxGetPr(prhs[1]);
  double *nSim =  mxGetPr(prhs[2]);
  
  /* Need to put the sim domain array into a vector class object */
  RealMatrix domainVector(1, (unsigned int) nSim[0]);
  domainVector.swallowFlatArray(simDomain, (unsigned int) nSim[0]); 
  
  /* The returned value of lambda */ 
  plhs[0] = mxCreateDoubleMatrix(1, 1, mxREAL);  
  double *lambda = mxGetPr(plhs[0]); 

  /* The returned value of gamma */
  plhs[1] = mxCreateDoubleMatrix(1, 1, mxREAL);  
  double *gamma = mxGetPr(plhs[1]); 

  /* The approximation error */
  plhs[2] = mxCreateDoubleMatrix(1, 1, mxREAL);  
  double *err = mxGetPr(plhs[2]); 
  
  err[0] = 0.0; // Placeholder

  /* Call the computational routine */
 
  bool result = getLambdaGamma( domainVector, classMean[0], lambda[0], gamma[0]);


  return;
}
