function responsibility = computeResponsibility(simVec, lambda, ...
  gamma, componentWeights, componentPriors)
%computeResponsibility - compute EM model responsibility for a sample.
% Compute the responsibilities of a mixture SDA model's components for a
% sample. This function is designed for EM adaptation of mixture SDA
% models.
% USAGE
% responsibility = computeResponsibility(simVec, lambda, gamma, ...
%   componentWeights, componentPriors)
% simVec: vector of similarities to each component centroids.
% lambda: component SDA lambdas, taken from modelParams.
% gamma: component SDA gammas, taken fom modelParams.
% componentWeights: mixture component weights, taken form modelParams.
% componentPriors: mixture component priors, taken form modelParams. 
%
% See also computeMixtureSdaWeights(), computeMixtureSdaModels()

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory, University of Washington, March 2007.
%$Id:$
%$DateTime:$
%$Author:$


exponentMat = lambda .* simVec;
probMat = gamma .* exp(exponentMat);
weightedProbMat = probMat .* componentWeights .* componentPriors;
normFactor = sum(weightedProbMat,2);
normFactor = repmat(normFactor, 1, size(weightedProbMat,2) );
responsibility = weightedProbMat ./ normFactor;

return
