function regularizingParams = createRegularizingParamStruct(...
  modelParams, nNeighbors, regParam)
%createRegularizingParamStruct - creates a regularizing parameter structure.
% Copies the appropriate fields from an input structure and adds and
% initializes other fields to create a parameter structure suitable for
% input to classifyAverageLocalSda(). 
%
% USAGE
% regStruct = createRegularizingParamStruct(inStruct, nNeighbors, regParam)
% inStruct - structure returned by computeAverageLocalSdaModels().
% nNeighbors - neighborhood size to use.
% regParam - regularizing parameter to use.
% regStruct - resulting structure suitable for classifyAverageLocalSda().
%    The fields are:
%    regType - string denoting the type of regularization.
%    centroidType - string denoting the type of centroid.
%    nNeighbors - the number of neighbors to use.
%    regParam - value of the regularization parameter to use. 
%    pmfs - C-by-C cell array of regularizing, class-conditional similarity
%        pmfs corresponding to the number of neighbors to be used, where C
%        is the number of classes.
%    simDomain - vector of possible similarity values.
%    classPriors - the class priors.
%
% See also classifyAverageLocalSda, computeAverageLocalSdaModels.

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory - University of Washington, Jan. 2009.
%$Id:$
%$DateTime:$
%$Author:$

regularizingParams.regType = modelParams.regType;
regularizingParams.centroidType = modelParams.centroidType;
regularizingParams.classPriors = modelParams.classPriors;
regularizingParams.neighborType = modelParams.neighborType;
regularizingParams.classLabels = modelParams.classLabels;
regularizingParams.nNeighbors = nNeighbors;
regularizingParams.regParam = regParam;

neighborVecIdx = modelParams.neighborhoodSizes == nNeighbors;
regularizingParams.avgMarginalConditionalLocalSdaPmfs = ...
  modelParams.avgMarginalConditionalLocalSdaPmfs(:,:,neighborVecIdx);
%try
regularizingParams.avgSimToCentroidHistPmfs = ...
  modelParams.avgSimToCentroidHistPmfs{neighborVecIdx};
%catch
  %disp(lasterr)
  %keyboard
%end
regularizingParams.avgAcrossClasses = ...
  modelParams.avgAcrossClasses(:,neighborVecIdx);

regularizingParams.simDomain = modelParams.simDomain;


return